module.exports = defineTest({
	description: 'inserts semicolons correctly when modifying SystemJS exports',
	formats: ['system']
});
